/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.repository');



org.ametys.repository.defaultSort = 'document';

org.ametys.repository.HomePage = function()
{
}

org.ametys.repository.HomePage._tabs = [];

org.ametys.repository.HomePage.initTabs = function(customTabs, standalone)
{
    org.ametys.repository.HomePage._tabs.push(new org.ametys.repository.JCRViewTab(standalone));
    
    for (var i = 0; i &lt; customTabs.length; i++)
    {
        org.ametys.repository.HomePage._tabs.push(customTabs[i]);
    }
    
    org.ametys.repository.HomePage._tabs.push(new org.ametys.repository.AdminTab());
    org.ametys.repository.HomePage._tabs.push(new org.ametys.repository.ConsoleTab());
}


/**
 * Create the panel
 */
org.ametys.runtime.HomePage.createPanel = function ()
{
	// Request isStandalone or not ?
	var serverMessage = new org.ametys.servercomm.ServerMessage('_' + context.workspaceName, 'repository/is-standalone',
			{}, 
			org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS,  
			null, 
			this,
			null);
	
	var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
	
	if (org.ametys.servercomm.ServerComm.handleBadResponse("<i18n:text i18n:key="ERROR_MSG_IS_STANDALONE"/>", response, "org.ametys.cms.tool.user.Edit"))
	{
		return;
	}
	
	var isStandalone = response.selectSingleNode("response").selectSingleNode("isStandalone")[org.ametys.servercomm.ServerComm.xmlTextContent];

	if (isStandalone=="false")
	{
	    // Embedded mode: initialize the tabs.
	    org.ametys.repository.HomePage.initTabs(customTabs, false);
	}
	else
	{
		var alreadyReg = response.selectSingleNode("response").selectSingleNode("alreadyRegistered")[org.ametys.servercomm.ServerComm.xmlTextContent];

		if (alreadyReg=="false")
		{	
		    // If unregistered, show the connect box, but do not initialize the tabs.
			org.ametys.repository.actions.Connect ();
		}
		else
		{
			// If standalone, but already registered, create the tabs.
		    org.ametys.repository.HomePage.initTabs(customTabs, true);
		}
	}
	
	org.ametys.repository.defaultSort = response.selectSingleNode('response').selectSingleNode('default-sort-order')[org.ametys.servercomm.ServerComm.xmlTextContent];

	/**
	 * Returns the global planel
	 */
	return new Ext.TabPanel ({
		id: 'global-tab-panel',
        activeTab: 0,
		items: org.ametys.repository.HomePage._tabs
	});
}
